@@ -5,7 +5,7 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING, TypeVar
 
 from sqlspec.config import GenericDatabaseConfig
-from sqlspec.utils.empty import Empty
+from sqlspec.typing import Empty, EmptyType
 
 if TYPE_CHECKING:
     from collections.abc import Generator
@@ -13,8 +13,6 @@ if TYPE_CHECKING:
 
     from adbc_driver_manager.dbapi import Connection, Cursor
 
-    from sqlspec.utils.empty import EmptyType
-
 __all__ = ("AdbcDatabaseConfig",)
 
 ConnectionT = TypeVar("ConnectionT", bound="Connection")
